@@ -1,4 +1,4 @@
-/* $Id: gdict-defbox.c,v 1.34 2004/12/16 15:52:42 vnoel Exp $ */
+/* $Id: gdict-defbox.c,v 1.35 2005/01/05 14:27:58 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -268,8 +268,11 @@ gdict_defbox_find (GDictDefbox *defbox, const gchar *text, gboolean start)
     	
     	if (mark)
     	    gtk_text_buffer_get_iter_at_mark (buffer, &iter, mark);
-    	else
-    	    iter = start_iter;
+    	else {
+		GDictWindow *gdict = defbox->gdict;
+		gtk_statusbar_pop (GTK_STATUSBAR (gdict->statusbar), 0);
+		iter = start_iter;
+	}
     }
     
     if (gtk_text_iter_forward_search (&iter, text,
