@@ -1,7 +1,7 @@
 #ifndef __GDICT_DEFBOX_H_
 #define __GDICT_DEFBOX_H_
 
-/* $Id: gdict-defbox.h,v 1.7 2004/11/03 10:02:29 pborelli Exp $ */
+/* $Id: gdict-defbox.h,v 1.11 2004/12/13 20:10:20 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -15,12 +15,7 @@
  *
  */
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
 #include <gtk/gtk.h>
-
 #include "dict.h"
 
 #define GDICT_TYPE_DEFBOX            (gdict_defbox_get_type ())
@@ -33,13 +28,15 @@ extern "C" {
 typedef struct _GDictDefbox        GDictDefbox;
 typedef struct _GDictDefboxClass   GDictDefboxClass;
 
+#include "gdict-app.h"
+
 struct _GDictDefbox 
 {
-    GtkTextView         text;
-    
+    GtkTextView    text;
     dict_context_t *context;
     dict_command_t *def_cmd;
     gchar          *database;
+    gpointer       gdict;
 };
 
 struct _GDictDefboxClass 
@@ -54,8 +51,8 @@ struct _GDictDefboxClass
 };
 
 GType	   gdict_defbox_get_type   (void);
+GtkWidget *gdict_defbox_new        (gpointer gdict);
 
-GtkWidget *gdict_defbox_new        (void);
 void 	   defbox_setup_tags 	   (GDictDefbox *defbox);
 
 gint       gdict_defbox_lookup     (GDictDefbox *defbox, gchar *text);
@@ -63,16 +60,9 @@ void       gdict_defbox_clear      (GDictDefbox *defbox);
 gboolean   gdict_defbox_find       (GDictDefbox *defbox, const gchar *text,
                                     gboolean start);
 void       gdict_defbox_reset      (GDictDefbox *defbox,
-                                    dict_context_t *context);
-
-#ifdef HAVE_GNOME_PRINT
-void       gdict_defbox_print      (GDictDefbox *defbox);
-#endif
-
+				    dict_context_t *context);
+void gdict_defbox_prepare_print    (GDictDefbox *defbox);
+void gdict_defbox_print_preview (GDictDefbox *defbox);
 gchar     *gdict_defbox_get_word   (GDictDefbox *defbox);
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
+	
 #endif /* __GDICT_DEFBOX_H_ */
