@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.57 2004/12/17 17:15:17 vnoel Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.62 2005/01/04 21:51:54 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -238,11 +238,10 @@ create_dictionary_panel (GDictPrefDialog *pref_dialog)
 
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_box_set_spacing (GTK_BOX (vbox), 2);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
+    gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
     
     pref_dialog->table = GTK_TABLE (gtk_table_new (4, 2, FALSE));
     gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (pref_dialog->table), FALSE, FALSE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (pref_dialog->table), 5);
     gtk_table_set_row_spacings (pref_dialog->table, 6);
     gtk_table_set_col_spacings (pref_dialog->table, 12);
     
@@ -340,15 +339,17 @@ create_websites_panel (GDictPrefDialog *pref_dialog)
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
 		
-	const gchar *column_titles[] = { N_(""), N_("Website"), N_("Search Address"), NULL };
+	const gchar *column_titles[] = { NULL, N_("Web Site"), N_("Search Address"), NULL };
 
-	vbox = gtk_vbox_new (FALSE, 5);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled), 
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
+	                                     GTK_SHADOW_IN);
 	gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, 0);
 
 	store = gtk_list_store_new (NUM_COLUMNS, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_STRING,
@@ -365,7 +366,7 @@ create_websites_panel (GDictPrefDialog *pref_dialog)
 							   "active", ENABLED, NULL);
 	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 	gtk_tree_view_column_set_resizable (column, FALSE);
-	gtk_tree_view_column_set_clickable (column, TRUE);
+	gtk_tree_view_column_set_clickable (column, FALSE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (view), column);
 
 	for (i=1; column_titles[i]; i++) {
@@ -411,15 +412,13 @@ static void
 gdict_pref_dialog_set (GDictPrefDialog *pref_dialog)
 {
 	gchar *port_str;
-	GDictPref *pref = pref_dialog->pref;
+	GDictPref *pref = pref_dialog->gdict->pref;
 	GDictWindow *gdict = pref_dialog->gdict;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	GSList *site_list;
 	GDictWebSearchSite *site;
 
-	pref_dialog->database = pref->database;
-	pref_dialog->dfl_strat = pref->dfl_strat;
 	if (pref->server != NULL)
 		gtk_entry_set_text (GTK_ENTRY (pref_dialog->server_entry),
 				    pref->server);
@@ -463,6 +462,7 @@ gdict_pref_dialog_init (GDictPrefDialog *pref_dialog)
     gtk_window_set_title (GTK_WINDOW (pref_dialog), _("Dictionary Preferences"));
     gtk_window_set_resizable (GTK_WINDOW (pref_dialog), TRUE);
     gtk_container_set_border_width (GTK_CONTAINER (pref_dialog), 5);
+    gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox), 2);
 
     notebook = gtk_notebook_new ();
  
@@ -471,7 +471,7 @@ gdict_pref_dialog_init (GDictPrefDialog *pref_dialog)
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
 
     vbox = create_websites_panel (pref_dialog);
-    label = gtk_label_new (_("Web sites"));
+    label = gtk_label_new (_("Web Sites"));
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
 
     gtk_container_add (GTK_CONTAINER(GTK_DIALOG (pref_dialog)->vbox), notebook);
@@ -506,7 +506,7 @@ gdict_pref_dialog_finalize (GObject *object)
 }
 
 GtkWidget *
-gdict_pref_dialog_new (GDictWindow *gdict, GDictPref *pref)
+gdict_pref_dialog_new (GDictWindow *gdict)
 {
     GDictPrefDialog *pref_dialog;
     dict_context_t *context = gdict->context;
@@ -516,7 +516,6 @@ gdict_pref_dialog_new (GDictWindow *gdict, GDictPref *pref)
 
     pref_dialog = GDICT_PREF_DIALOG (g_object_new (GDICT_TYPE_PREF_DIALOG, NULL));
     pref_dialog->gdict = gdict;
-    pref_dialog->pref = pref;
     pref_dialog->context = context;
     gdict_pref_dialog_set (pref_dialog);
 
@@ -541,12 +540,11 @@ pref_set_db_cb (GtkWidget *widget, gpointer data)
 
     pref_dialog = GDICT_PREF_DIALOG (data);
     gdict = pref_dialog->gdict;
-    pref_dialog->database = g_object_get_data (G_OBJECT (widget), "db_name");
-    pref_dialog->pref->database = pref_dialog->database;
+    gdict->pref->database = g_object_get_data (G_OBJECT (widget), "db_name");
 
-    gdict_set_gconf_string (pref_dialog->gdict, "database", pref_dialog->database);
+    gdict_set_gconf_string (gdict, "database", gdict->pref->database);
     if (gdict->speller_visible)
-	    gdict_speller_change_db (gdict->speller, pref_dialog->database);
+	    gdict_speller_change_db (gdict->speller, gdict->pref->database);
 }
 
 /* pref_set_strat_cb
@@ -562,12 +560,11 @@ pref_set_strat_cb (GtkWidget *widget, gpointer data)
     
     pref_dialog = GDICT_PREF_DIALOG (data);
     gdict = pref_dialog->gdict;
-    pref_dialog->dfl_strat = g_object_get_data (G_OBJECT (widget), "strat_name");
-    pref_dialog->pref->dfl_strat = pref_dialog->dfl_strat;
+    gdict->pref->dfl_strat = g_object_get_data (G_OBJECT (widget), "strat_name");
 
-    gdict_set_gconf_string (gdict, "strategy", pref_dialog->dfl_strat);
+    gdict_set_gconf_string (gdict, "strategy", gdict->pref->dfl_strat);
     if (gdict->speller_visible)
-	    gdict_speller_change_strategy (gdict->speller, pref_dialog->dfl_strat);
+	    gdict_speller_change_strategy (gdict->speller, gdict->pref->dfl_strat);
 }
 
 /* pref_dialog_add_db
@@ -580,6 +577,7 @@ pref_dialog_add_db (GDictPrefDialog *pref_dialog, gchar *db,
 		    gchar *desc) 
 {
     GtkWidget *menu_item;
+    GDictWindow *gdict = pref_dialog->gdict;
     
     menu_item = gtk_menu_item_new_with_label (desc);
     g_signal_connect (G_OBJECT (menu_item), "activate", 
@@ -588,9 +586,9 @@ pref_dialog_add_db (GDictPrefDialog *pref_dialog, gchar *db,
     gtk_widget_show (menu_item);
     gtk_menu_append (pref_dialog->db_list, menu_item);
 
-    if ((pref_dialog->database == NULL)
-		    || (!strcmp (pref_dialog->database, db)))
-      gtk_menu_set_active (pref_dialog->db_list, pref_dialog->database_idx);
+    if ((gdict->pref->database == NULL)
+	|| (!strcmp (gdict->pref->database, db)))
+	    gtk_menu_set_active (pref_dialog->db_list, pref_dialog->database_idx);
     pref_dialog->database_idx++;
 }
 
@@ -604,6 +602,7 @@ pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat,
 		       gchar *desc) 
 {
     GtkWidget *menu_item;
+    GDictWindow *gdict = pref_dialog->gdict;
     
     menu_item = gtk_menu_item_new_with_label (desc);
     g_signal_connect (G_OBJECT (menu_item), "activate", 
@@ -612,8 +611,8 @@ pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat,
     gtk_widget_show (menu_item);
     gtk_menu_append (pref_dialog->strat_list, menu_item);
     
-    if ((pref_dialog->dfl_strat == NULL)
-		    || (!strcmp (pref_dialog->dfl_strat, strat)))
+    if ((gdict->pref->dfl_strat == NULL)
+		    || (!strcmp (gdict->pref->dfl_strat, strat)))
 	gtk_menu_set_active (pref_dialog->strat_list,
 			     pref_dialog->dfl_strat_idx);
     pref_dialog->dfl_strat_idx++;
@@ -887,7 +886,7 @@ set_server_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
     g_return_val_if_fail (GDICT_IS_PREF_DIALOG (data), FALSE);
 
     pref_dialog = data;
-    pref = pref_dialog->pref;
+    pref = pref_dialog->gdict->pref;
     server = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->server_entry), 0, -1);
     if (!server)
         return FALSE;
@@ -922,7 +921,7 @@ set_port_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
     g_return_val_if_fail (GDICT_IS_PREF_DIALOG (data), FALSE);
 
     pref_dialog = data;
-    pref = pref_dialog->pref;
+    pref = pref_dialog->gdict->pref;
     port = gtk_editable_get_chars (GTK_EDITABLE (pref_dialog->port_entry), 0, -1);
     if (pref->port != atoi (port)) {
     
