@@ -1,4 +1,4 @@
-/* $Id: gdict-pref.c,v 1.25 2004/12/14 18:56:47 vnoel Exp $ */
+/* $Id: gdict-pref.c,v 1.26 2004/12/21 20:13:33 vnoel Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -189,12 +189,23 @@ smart_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
 }
 
 void
-gdict_window_store_geometry (GDictWindow *gdict)
+gdict_window_restore_position (GDictWindow *gdict)
+{
+	int x,y;
+	x = gdict_get_gconf_int (gdict, "window_x");
+	y = gdict_get_gconf_int (gdict, "window_y");
+	gtk_window_move (GTK_WINDOW (gdict), x, y);
+}
+
+void
+gdict_window_store_position (GDictWindow *gdict)
 {
 	int x, y;
 	gtk_window_get_position (GTK_WINDOW (gdict), &x, &y);
 	gdict->x = x;
 	gdict->y = y;
+	gdict_set_gconf_int (gdict, "window_x", x);
+	gdict_set_gconf_int (gdict, "window_y", y);
 }
 
 /* gdict_pref_load
