@@ -19,23 +19,18 @@
 
     ---------------------------------------------------------------------- */
 
-#include <config.h>
 #ifdef __CYGWIN__
 #define timezonevar
 #endif
-#include <gnome.h>
+#ifdef HAVE_LOCALE_H
 #include <locale.h>
-#include <errno.h>
+#endif
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+#include <string.h>
 #include "logview.h"
 #include "logrtns.h"
-
-/*
- * -----------------
- * Local definitions
- * ------------------
- */
-
-#define MAX_NUM_LOGS             10
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
 
 /*
  * -------------------
@@ -43,11 +38,13 @@
  * -------------------
  */
 
-int match_line_in_db (LogLine *line, GList *db);
-void UpdateLastPage (Log *log);
+static int isSameDay (time_t day1, time_t day2);
+static void ReadLogStats (Log * log, gchar **buffer_lines);
+static gboolean file_exist (char *filename, gboolean show_error);
 
 extern GList *regexp_db;
 extern GList *actions_db;
+const char *error_main = N_("The file could not be opened");
 
 /*
  * -------------------
@@ -166,7 +163,20 @@ get_month (const char *str)
 	return 12;
 }
 
+static gboolean
+file_is_zipped (char *filename)
+{
+	char *mime_type;
 
+	mime_type = gnome_vfs_get_mime_type (filename);
+
+	if (strcmp (mime_type, "application/x-gzip")==0 ||
+	    strcmp (mime_type, "application/x-zip")==0 ||
+	    strcmp (mime_type, "application/zip")==0)
+		return TRUE;
+	else
+		return FALSE;
+}
 
 /* ----------------------------------------------------------------------
    NAME:          OpenLogFile
@@ -178,343 +188,210 @@ OpenLogFile (char *filename)
 {
    Log *tlog;
    LogLine *line;
-   char buffer[1024];
+   char *buffer;
+   char **buffer_lines;
+   char *display_name=NULL;
+   int i;
+   GError *error;
+   GnomeVFSResult result;
+   int size;
+   
+   if (file_exist (filename, TRUE) == FALSE)
+	   return NULL;
 
-   /* Check that the file exists and is readable and is a
-      logfile */
-   if (!isLogFile (filename))
-      return (Log *) NULL;
+   if (file_is_zipped (filename)) {
+	   display_name = filename;
+	   filename = g_strdup_printf ("%s#gzip:", display_name);
+   }   
 
-   /* Alloc memory for  log structures -------------------- */
-   tlog = malloc (sizeof (Log));
-   if (tlog == NULL)
-   {
-      ShowErrMessage (_("Not enough memory!\n"));
-      return ((Log *) NULL);
+   /* Check that the file is readable and is a logfile */
+   if (!isLogFile (filename, TRUE))
+	   return NULL;
+
+   result = gnome_vfs_read_entire_file (filename, &size, &buffer);
+   if (result != GNOME_VFS_OK) {
+	   ShowErrMessage (NULL, error_main, _("Unable to open logfile!\n"));
+	   return NULL;
    }
-   memset (tlog, 0, sizeof (Log));
 
-   /* Open log files ------------------------------------- */
+   /* Alloc memory for log structure */
+   tlog = g_new0 (Log, 1);
+   if (tlog == NULL) {
+	   ShowErrMessage (NULL, error_main, _("Not enough memory!\n"));
+	   return NULL;
+   }
    strncpy (tlog->name, filename, sizeof (tlog->name)-1);
    tlog->name[sizeof (tlog->name) - 1] = '\0';
-   tlog->fp = fopen (filename, "r");
-   if (tlog->fp == NULL)
-   {
-      ShowErrMessage (_("Unable to open logfile!\n"));
-      return (Log *) NULL;
-   }
-   /* fseek (tlog->fp, -1L, SEEK_END); */
+   tlog->display_name = display_name;
+   if (display_name)
+	   g_free (filename);
 
-   while (fgets (buffer, sizeof (buffer), tlog->fp)) {
+   buffer_lines = g_strsplit (buffer, "\n", -1);
 
-      ++(tlog->total_lines);
-      tlog->lines = realloc (tlog->lines, sizeof(*(tlog->lines)) * tlog->total_lines);
-      if (!tlog->lines) {
-         ShowErrMessage ("Unable to realloc for lines\n");
-         return (Log *) NULL;
-      }
+   /* count the lines */
+   for (i=0; buffer_lines[i+1] != NULL; i++);
+   tlog->total_lines = i;
 
-      line = malloc (sizeof(**(tlog->lines)));
-      if (!line) {
-         ShowErrMessage ("Unable to malloc for lines[i]\n");
-         return (Log *) NULL;
-      }
-      ParseLine (buffer, line);
-      (tlog->lines)[tlog->total_lines - 1] = line;
-   }
+   tlog->lines = g_malloc (sizeof (*(tlog->lines)) * tlog->total_lines);
+   for (i=0; buffer_lines[i+1] != NULL; i++) {	   
+	   line = g_malloc (sizeof(**(tlog->lines)));
+	   if (!line) {
+		   ShowErrMessage (NULL, error_main, "Unable to malloc for lines[i]\n");
+		   return NULL;
+	   }
+	   ParseLine (buffer_lines[i], line);
+	   (tlog->lines)[i] = line;
+   }   
 
    /* Read log stats */
-   ReadLogStats (tlog);
-
-   fseek(tlog->fp, 0L, SEEK_END); 
-   tlog->offset_end = ftell(tlog->fp);
-
-   if (!tlog->offset_end)
-      printf ("Empty file! \n");
+   ReadLogStats (tlog, buffer_lines);
+   g_strfreev (buffer_lines);
 
    /* initialize date headers hash table */
-   tlog->date_headers = g_hash_table_new_full (
-                NULL, NULL, NULL, (GDestroyNotify) gtk_tree_path_free);
+   tlog->date_headers = g_hash_table_new_full (NULL, NULL, NULL, 
+					       (GDestroyNotify) gtk_tree_path_free);
    tlog->first_time = TRUE;
    return tlog;
 
 }
 
+static gboolean
+file_exist (char *filename, gboolean show_error)
+{
+   GnomeVFSHandle *handle;
+   GnomeVFSResult result;
+   char buff[1024];
+
+   result = gnome_vfs_open (&handle, filename, GNOME_VFS_OPEN_READ);
+   if (result != GNOME_VFS_OK) {
+	   if (show_error) {
+		   switch (result) {
+		   case GNOME_VFS_ERROR_ACCESS_DENIED:
+		   case GNOME_VFS_ERROR_NOT_PERMITTED:
+			   g_snprintf (buff, sizeof (buff),
+				       _("%s is not user readable. "
+					 "Either run the program as root or ask the sysadmin to "
+					 "change the permissions on the file."), filename);
+			   break;
+		   case GNOME_VFS_ERROR_TOO_BIG:
+			   g_snprintf (buff, sizeof (buff), _("%s is too big."));
+			   break;
+		   default:
+			   g_snprintf (buff, sizeof (buff),
+				       _("%s could not be opened."), filename);
+		   }
+		   ShowErrMessage (NULL, error_main, buff);
+	   }
+	   return FALSE;
+   }
+
+   gnome_vfs_close (handle);
+   return TRUE;
+}
+
 /* ----------------------------------------------------------------------
    NAME:          isLogFile
    DESCRIPTION:   Check that the given file is indeed a logfile and 
    that it is readable.
    ---------------------------------------------------------------------- */
 int
-isLogFile (char *filename)
+isLogFile (char *filename, gboolean show_error)
 {
-   struct stat fstatus;
    char buff[1024];
-   char *token;
+   char **token;
+   char *found_space;
    int i;
-   FILE *fp;
+   GnomeVFSHandle *handle;
+   GnomeVFSResult result;
+   GnomeVFSFileSize size;
 
-   stat (filename, &fstatus);
-
-   /* Check that its a regular file       */
-   if (!S_ISREG (fstatus.st_mode))
-   {
-      g_snprintf (buff, sizeof (buff),
-		  _("%s is not a regular file."), filename);
-      ShowErrMessage (buff);
-      return FALSE;
-   }
-   /* File unreadable                     */
-   if ((fstatus.st_mode & S_IRUSR) == 0)
-   {
-      g_snprintf (buff, sizeof (buff),
-		  _("%s is not user readable. "
-      "Either run the program as root or ask the sysadmin to "
-      "change the permissions on the file."), filename);
-      ShowErrMessage (buff);
-      return FALSE;
-   }
    /* Read first line and check that it has the format
-      of a log file: Date ...
-    */
-   fp = fopen (filename, "r");
-   if (fp == NULL)
-   {
-      /* FIXME: this error message is really quite poor
-       * we should state why the open failed
-       * ie. file too large etc etc..
-       */
-      g_snprintf (buff, sizeof (buff),
-		  _("%s could not be opened."), filename);
-      ShowErrMessage (buff);
-      return FALSE;
-   }
-   if (fgets (buff, sizeof (buff), fp) == NULL) {
-       /* Either an error, or empty log */
-       fclose (fp);
-       if (feof(fp)) 
-           /* EOF -> empty file, still a valid log though */
-           return TRUE;
-       else 
-           /* !EOF -> read error */
-           return FALSE;
-   }
-   fclose (fp);
-   token = strtok (buff, " ");
-   /* This is not a good assumption I don't think, especially
-    * if log is internationalized
-    * -George
-   if (strlen (buff) != 3)
-   {
-      g_snprintf (buff, sizeof (buff),
-		  _("%s not a log file."), filename);
-      ShowErrMessage (buff);
-      return FALSE;
-   }
-   */
+    * of a log file: Date ...    */
+   result = gnome_vfs_open (&handle, filename, GNOME_VFS_OPEN_READ);
+   if (result != GNOME_VFS_OK)
+	   return FALSE;
 
-   if (token == NULL)
-   {
-      g_snprintf (buff, sizeof (buff), _("%s not a log file."), filename);
-      ShowErrMessage (buff);
-      return FALSE;
+   result = gnome_vfs_read (handle, buff, sizeof(buff), &size);
+   gnome_vfs_close (handle);
+   if (result != GNOME_VFS_OK)
+	   return FALSE;
+   
+   found_space = g_strstr_len (buff, 1024, " ");
+   if (found_space == NULL) {
+	   if (show_error) {
+		   g_snprintf (buff, sizeof (buff), _("%s not a log file."), filename);
+		   ShowErrMessage (NULL, error_main, buff);
+	   }
+	   return FALSE;
+   }
+   
+   token = g_strsplit (buff, " ", 1);
+   i = get_month (token[0]);
+   g_strfreev (token);
+   if (i == 12) {
+	   if (show_error) {
+		   g_snprintf (buff, sizeof (buff), _("%s not a log file."), filename);
+		   ShowErrMessage (NULL, error_main, buff);
+	   }
+	   return FALSE;
    }
 
-   i = get_month (token);
-
-   if (i == 12)
-   {
-      g_snprintf (buff, sizeof (buff), _("%s not a log file."), filename);
-      ShowErrMessage (buff);
-      return FALSE;
-   }
    /* It looks like a log file... */
    return TRUE;
 }
 
-/* ----------------------------------------------------------------------
-   NAME:        ReadNPagesUp
-   DESCRIPTION: 
-   ---------------------------------------------------------------------- */
 
-#ifdef FIXME
-int
-ReadNPagesUp (Log * lg, Page * pg, int n)
+gchar **ReadLastPage (Log *log)
 {
-   Page *cp;
-   int i;
+	GnomeVFSResult result;
+	gchar *buffer;
+	int size;
 
-   /* Go to place on file. */
-   fseek (lg->fp, pg->firstchpos, SEEK_SET);
+	g_return_val_if_fail (log, NULL);
 
-   cp = pg->prev;
-   /* Read n pages up.             */
-   for (i = 0; i < n; i++)
-   {
-      ReadPageUp (lg, cp);
-      lg->firstpg = cp;
-      lg->lastpg = lg->lastpg->prev;
-      if (cp->isfirstpage == TRUE)
-	 return i+1;
-      cp = cp->prev;
-   }
-
-   return n;
+	result = gnome_vfs_read_entire_file (log->name, &size, &buffer);
+	
+	if (size > 0 && buffer != NULL) {
+		gchar **buffer_lines;
+		result = gnome_vfs_open (&(log->mon_file_handle), log->name, GNOME_VFS_OPEN_READ);
+		log->mon_offset = size;
+		buffer_lines = g_strsplit (buffer, "\n", -1);
+		g_free (buffer);
+		return buffer_lines;
+	}
+	return NULL;
 }
 
-/* ----------------------------------------------------------------------
-   NAME:        ReadNPagesDown
-   DESCRIPTION: 
-   ---------------------------------------------------------------------- */
-
-int
-ReadNPagesDown (Log * lg, Page * pg, int n)
+gchar **ReadNewLines (Log *log)
 {
-   Page *cp;
-   int i;
+	GnomeVFSFileSize bytes_read;
+	GnomeVFSFileInfo info;
+	GnomeVFSResult result;
+	gchar *buffer;
+	
+	g_return_val_if_fail (log, NULL);
+	g_return_val_if_fail (log->mon_file_handle, NULL);
+	
+	result = gnome_vfs_get_file_info_from_handle (log->mon_file_handle, &info, GNOME_VFS_FILE_INFO_DEFAULT);
+	buffer = g_malloc (info.size - log->mon_offset);
 
-   /* Go to place on file. */
-   fseek (lg->fp, pg->lastchpos, SEEK_SET);
-
-   cp = pg->next;
-   /* Read n pages down.   */
-   for (i = 0; i < n; i++)
-   {
-      ReadPageDown (lg, cp, FALSE /* exec_actions */);
-      lg->lastpg = cp;
-      lg->firstpg = lg->firstpg->next;
-      if (cp->islastpage == TRUE)
-	 return i+1;
-      cp = cp->next;
-   }
-
-   return n;
+	result = gnome_vfs_seek (log->mon_file_handle, GNOME_VFS_SEEK_START, log->mon_offset);
+	result = gnome_vfs_read (log->mon_file_handle, buffer, info.size - log->mon_offset, &bytes_read);
+	
+	if (result == GNOME_VFS_OK && bytes_read > 0) {
+		gchar **buffer_lines;
+		log->mon_offset = info.size;
+		result = gnome_vfs_tell (log->mon_file_handle, &(log->mon_offset));
+		buffer_lines = g_strsplit (buffer, "\n", -1);
+		g_free (buffer);
+		return buffer_lines;
+	}
 }
 
-/* ----------------------------------------------------------------------
-   NAME:        ReadPageUp
-   DESCRIPTION: Reads a page from the log file.
-   ---------------------------------------------------------------------- */
-
-int
-ReadPageUp (Log * lg, Page * pg)
-{
-   LogLine *line;
-   FILE *fp;
-   char *c, buffer[R_BUF_SIZE + 1];
-   int ch;
-   int ln;
-   long int old_pos;
-
-   fp = lg->fp;
-   ln = LINES_P_PAGE - 1;
-
-   pg->lastchpos = ftell (fp);
-   pg->islastpage = FALSE;
-   pg->isfirstpage = FALSE;
-   pg->fl = 0;
-   pg->ll = LINES_P_PAGE - 1;
-
-   /* Tell if we are reading the last page */
-   ch = fgetc (fp);
-   if (ch == EOF)
-     pg->islastpage = TRUE;
-   ungetc (ch,fp);
-
-   while (ln >= pg->fl)
-   {
-      c = buffer;
-      if (fseek (fp, -1L, SEEK_CUR) < 0)
-      {
-	 pg->fl = ln;
-	 pg->isfirstpage = TRUE;
-	 break;
-      }
-      /* Go to end of previous line */
-      ch = fgetc (fp);
-      while (ch != '\n')
-      {
-	 if (fseek (fp, -2L, SEEK_CUR) < 0)
-	 {
-	    /*   ch = fgetc (fp); */
-	    pg->isfirstpage = TRUE;
-	    pg->fl = ln;
-	    break;
-	 }
-	 ch = fgetc (fp);
-      }
-      ungetc (ch, fp);
-
-      /* Read the line now. */
-      old_pos = ftell (fp);
-      if (pg->isfirstpage == FALSE)
-	 fseek (fp, 1L, SEEK_CUR);
-      fgets (buffer, R_BUF_SIZE, fp);
-
-      /* Put cursor back where it was. */
-      fseek (fp, old_pos, SEEK_SET);
-
-      line = &pg->line[ln];
-      ParseLine (buffer, line);
-      ln--;
-   }
-   pg->firstchpos = ftell (fp);
-
-   return pg->isfirstpage;
-}
-#endif
-
-/* ----------------------------------------------------------------------
-   NAME:        ReadPageDown
-   DESCRIPTION: Reads new log lines 
-   ---------------------------------------------------------------------- */
-
-int
-ReadPageDown (Log *log, LogLine ***inp_mon_lines, gboolean exec_actions)
-{
-   char buffer[1024];
-   gint new_lines_read = 0;
-   FILE *fp;
-   LogLine *line;
-   LogLine **new_mon_lines = NULL;
-   
-   g_return_val_if_fail (log != NULL, FALSE);
-
-   fp = log->fp;
-
-   while (fgets (buffer, sizeof (buffer), fp)) {
-       ++new_lines_read;
-       new_mon_lines = realloc (new_mon_lines,
-               sizeof(*(new_mon_lines)) * new_lines_read);
-
-       if (!new_mon_lines) {
-           ShowErrMessage ("Unable to realloc for new_mon_lines\n");
-           return 0; 
-       }
-
-       line = malloc (sizeof(**(new_mon_lines)));
-       if (!line) {
-           ShowErrMessage ("Unable to malloc for line\n");
-           return 0;
-       }
-       ParseLine (buffer, line);
-       new_mon_lines[new_lines_read - 1] = line;
-
-       if (exec_actions)
-           exec_action_in_db (log, line, actions_db);
-   }
-   *inp_mon_lines = new_mon_lines;
-   log->offset_end = ftell (fp);
-
-   return new_lines_read;
-
-}
-
-
 /* ----------------------------------------------------------------------
    NAME:        ParseLine
    DESCRIPTION: Extract date and other info from the line. If any field 
-   seems to be missing fill the others with -1 and NULL.
+   seems to be missing fill the others with -1 and "".
    ---------------------------------------------------------------------- */
 
 void
@@ -528,7 +405,7 @@ ParseLine (char *buff, LogLine * line)
    strncpy (line->message, buff, MAX_WIDTH);
    line->message[MAX_WIDTH-1] = '\0';
 
-   token = strtok (buff, " ");
+   token = strtok (line->message, " ");
    if (token == NULL) return;
    /* This is not a good assumption I don't think, especially
     * if log is internationalized
@@ -653,17 +530,6 @@ ParseLine (char *buff, LogLine * line)
       line->message [MAX_WIDTH-1] = '\0';
    }
 
-   /* Search current data base for string and attach descritpion */
-   /* -------------------------
-   if (regexp_db == NULL)
-     return;
-   if (match_line_in_db (line, regexp_db))
-     {
-       sprintf (scratch, _("Expression /%s/ matched."),
-		 line->description->regexp);
-       line->description->description = g_strdup(scratch);
-     }
-     ---------------------------- */
 }
 
 /* ----------------------------------------------------------------------
@@ -673,20 +539,21 @@ ParseLine (char *buff, LogLine * line)
    All dates are given with respect to the 1/1/1970
    and are then corrected to the correct year once we
    reach the end.
+   buffer_lines must NOT be freed.
    ---------------------------------------------------------------------- */
 
-void
-ReadLogStats (Log * log)
+static void
+ReadLogStats (Log *log, gchar **buffer_lines)
 {
-   FILE *fp;
-   char buffer[256];
-   long filemark;
+   gchar *buffer;
    int offsetyear, lastyear, thisyear;
-   int nl;
+   int nl, i;
    time_t curdate, newdate, correction;
    DateMark *curmark;
    struct stat filestat;
    struct tm *tmptm, footm;
+   GnomeVFSResult result;
+   GnomeVFSFileInfo info;
 
    /* Clear struct.      */
    log->lstats.startdate = 0;
@@ -695,85 +562,70 @@ ReadLogStats (Log * log)
    log->lstats.mtime = 0;
    log->lstats.size = 0;
 
-   fp = log->fp;
-   if (fp == NULL)
-      return;
-
-   rewind (fp);
-   stat (log->name, &filestat);
-   log->lstats.mtime = filestat.st_mtime;
-   log->lstats.size = filestat.st_size;
+   result = gnome_vfs_get_file_info (log->name, &info, GNOME_VFS_FILE_INFO_DEFAULT);
+   log->lstats.mtime = info.mtime;
+   log->lstats.size = info.size;
 
    /* Make sure we have at least a starting date. */
    nl = 0;
    curdate = -1;
-   while (curdate < 0)
+   while ((curdate < 0) && (buffer_lines[nl]!=NULL))
    {
-      filemark = ftell (fp);
-      if (fgets (buffer, 255, fp) == NULL)
-	 return;
-      curdate = GetDate (buffer);
+	   curdate = GetDate (buffer_lines[nl]);	  
+	   nl++;
    }
    log->lstats.startdate = curdate;
-   nl++;
 
    /* Start building the list */
+
    offsetyear = 0;
    curmark = malloc (sizeof (DateMark));
-   if (curmark == NULL)
-   {
-      ShowErrMessage (_("ReadLogStats: out of memory"));
-      exit (0);
+   if (curmark == NULL) {
+	   ShowErrMessage (NULL, error_main, _("ReadLogStats: out of memory"));
+	   exit (0);
    }
-   log->lstats.firstmark = curmark;
    curmark->time = curdate;
    curmark->year = offsetyear;
    curmark->next = NULL;
    curmark->prev = NULL;
-   curmark->offset = filemark;
+   curmark->offset = info.size;
    curmark->ln = nl;
+   log->lstats.firstmark = curmark;
 
-   /* Count lines up to end */
-   filemark = ftell (fp);
-   while (fgets (buffer, 255, fp) != NULL)
-   {
-     nl++;
-     newdate = GetDate (buffer);
-     if (newdate < 0)
-       {
-	 /*  lines continues */
-	 nl--;
-	 continue;
-       }
-     if (isSameDay (newdate, curdate) )
-       {
-	 filemark = ftell (fp);
-	 continue;
-       }
-     curmark->next = malloc (sizeof (DateMark));
-     if (curmark->next == NULL)
-       {
-	 ShowErrMessage (_("ReadLogStats: out of memory"));
-	 exit (0);
-       }
-     curmark->next->prev = curmark;
-     curmark = curmark->next;
-     curmark->time = newdate;
-     if (newdate < curdate)	/* The newdate is next year */
-       offsetyear++;
-     curmark->year = offsetyear;
-     curmark->next = NULL;
-     curmark->offset = filemark;
-     curmark->ln = nl;
-     curdate = newdate;
-     filemark = ftell (fp);
+   /* Count days appearing in the log */
+
+   i = 0;
+   for (i=0; buffer_lines[i]!=NULL; i++) {
+	   newdate = GetDate (buffer_lines[i]);
+
+	   if (newdate < 0)
+		   continue;
+	   if (isSameDay (newdate, curdate) )
+		   continue;
+	   
+	   curmark->next = malloc (sizeof (DateMark));
+	   if (curmark->next == NULL) {
+		   ShowErrMessage (NULL, error_main, _("ReadLogStats: out of memory"));
+		   exit (0);
+	   }
+
+	   curmark->next->prev = curmark;
+	   curmark = curmark->next;
+	   curmark->time = newdate;
+	   if (newdate < curdate)	/* The newdate is next year */
+		   offsetyear++;
+	   curmark->year = offsetyear;
+	   curmark->next = NULL;
+	   curmark->ln = nl;
+	   curdate = newdate;
    }
-   
+   log->lstats.numlines = i;
    log->lstats.enddate = curdate;
 
    /* Correct years now. We assume that the last date on the log
       is the date last accessed */
-   curdate = filestat.st_mtime;
+
+   curdate = info.mtime;
    tmptm = localtime (&curdate);
    thisyear = tmptm->tm_year;
    lastyear = offsetyear;
@@ -782,224 +634,65 @@ ReadLogStats (Log * log)
    footm.tm_isdst = 0;
    footm.tm_mday = 1;
    curmark = log->lstats.firstmark;
-   while (curmark != NULL)
-   {
-      footm.tm_year = (curmark->year - lastyear) + thisyear;
-      correction = mktime (&footm);
-/*       fprintf (stderr, "Antes de corregir: [%s]\n", ctime (&curmark->time)); */
-      if (IsLeapYear (curmark->year - lastyear + thisyear))
-	 curmark->time += 24 * 60 * 60;		/*  Add one day */
 
+   while (curmark != NULL) {
+	   footm.tm_year = (curmark->year - lastyear) + thisyear;
+	   correction = mktime (&footm);
+	   if (IsLeapYear (curmark->year - lastyear + thisyear))
+		   curmark->time += 24 * 60 * 60;		/*  Add one day */
+	   
 #if defined(__NetBSD__) || defined(__FreeBSD__)
-      curmark->time += correction - tmptm->tm_gmtoff;
+	   curmark->time += correction - tmptm->tm_gmtoff;
 #else
-      curmark->time += correction - timezone;
+	   curmark->time += correction - timezone;
 #endif
-
-      memcpy (&curmark->fulldate, localtime (&curmark->time), sizeof (struct tm));
-
-/*       fprintf (stderr, "%s\n", ctime (&curmark->time)); */
-      if (curmark->next != NULL)
-	 curmark = curmark->next;
-      else
-      {
-	 log->lstats.lastmark = curmark;
-	 break;
-      }
+	   
+	   memcpy (&curmark->fulldate, localtime (&curmark->time), sizeof (struct tm));
+	   
+	   if (curmark->next != NULL)
+		   curmark = curmark->next;
+	   else {
+		   log->lstats.lastmark = curmark;
+		   break;
+	   }
    }
-
+   
    log->curmark = log->lstats.lastmark;
 
    /* Correct start and end year in lstats. */
    footm.tm_year = thisyear;
    correction = mktime (&footm);
    if (IsLeapYear (thisyear))
-      log->lstats.enddate += 24 * 60 * 60;	/*  Add one day */
-
+	   log->lstats.enddate += 24 * 60 * 60;	/*  Add one day */
+   
 #if defined(__NetBSD__) || defined(__FreeBSD__)
    log->lstats.enddate += correction - tmptm->tm_gmtoff;
 #else
    log->lstats.enddate += correction - timezone;
 #endif
-
+   
    footm.tm_year = thisyear - lastyear;
    correction = mktime (&footm);
    if (IsLeapYear (thisyear - lastyear))
-      log->lstats.startdate += 24 * 60 * 60;	/*  Add one day */
+	   log->lstats.startdate += 24 * 60 * 60;	/*  Add one day */
 
 #if defined(__NetBSD__) || defined(__FreeBSD__)
    log->lstats.startdate += correction - tmptm->tm_gmtoff;
 #else
    log->lstats.startdate += correction - timezone;
 #endif
-   log->lstats.numlines = nl;
-
-   return;
-}
-
-/* ----------------------------------------------------------------------
-   NAME:	UpdateLogStats
-   DESCRIPTION:	
-   ---------------------------------------------------------------------- */
-
-void
-UpdateLogStats( Log *log )
-{
-   FILE *fp;
-   char buffer[256];
-   long filemark;
-   int thisyear, nl;
-   time_t curdate, newdate;
-   DateMark *curmark;
-   struct tm *tmptm;
-
-   if (log == NULL)
-     return;
-
-   fp = log->fp;
-   if (fp == NULL)
-      return;
-
-   curmark = log->lstats.lastmark;
-   curdate = log->lstats.enddate;
-   tmptm = localtime (&curdate);
-   thisyear = tmptm->tm_year;
-   fseek( fp, curmark->offset, SEEK_SET);
-
-   /* Read last line again and discard it */
-   fgets (buffer, 255, fp);
-
-   /* Add all new entries to the list */
-   filemark = ftell (fp);
-   nl=0;
-   while (fgets (buffer, 255, fp) != NULL)
-   {
-     nl++;
-     newdate = GetDate (buffer);
-     if (newdate < 0 || isSameDay (newdate, curdate) )
-       {
-	 filemark = ftell (fp);
-	 continue;
-       }
-     curmark->next = malloc (sizeof (DateMark));
-     if (curmark->next == NULL)
-       {
-	 ShowErrMessage (_("ReadLogStats: out of memory"));
-	 exit (0);
-       }
-     curmark->next->prev = curmark;
-     curmark = curmark->next;
-     curmark->time = newdate;
-     if (newdate < curdate)	/* The newdate is next year */
-       thisyear++;
-     curmark->year = thisyear;
-     curmark->next = NULL;
-     curmark->offset = filemark;
-     curdate = newdate;
-     filemark = ftell (fp);
-   }
-   
-   log->lstats.enddate = curdate;
-   log->lstats.lastmark = curmark;
-   log->lstats.numlines += nl;
 
    return;
 }
 
 
 
-/* ----------------------------------------------------------------------
-   NAME:          MoveToMark
-   DESCRIPTION:   From the current mark read NUM_PAGES/2 pages ahead and
-                  NUM_PAGES/2 pages behind (if possible).
-   ---------------------------------------------------------------------- */
-
-#ifdef FIXME
-void
-MoveToMark (Log *log)
-{
-  DateMark *mark;
-  FILE *fp;
-  Page *middlepg;
-  int pagesread, pagesdown, i;
-  
-  g_return_if_fail (log);
-  
-  mark = log->curmark;
-  g_return_if_fail (mark);
-  fp = log->fp;
-  
-  pagesdown = NUM_PAGES>>1;
-  
-  /* Read relative to middle page */
-  middlepg = log->lastpg;
-  for(i=0;i<pagesdown;i++)
-    middlepg = middlepg->prev;
-  
-  /* Move file pointer to the current offset 
-     into the file */
-  if (mark->offset > 1)
-    fseek(fp, mark->offset-1, SEEK_SET);
-  else
-    fseek(fp, mark->offset, SEEK_SET);
-  ReadPageDown(log, middlepg, FALSE /* exec_actions */);
-  if (middlepg->islastpage)
-    {
-      middlepg = log->lastpg;
-      if (mark->offset > 1)
-	fseek(fp, mark->offset-1, SEEK_SET);
-      else
-	fseek(fp, mark->offset, SEEK_SET);
-      ReadPageDown(log, middlepg, FALSE /* exec_actions */);
-      ReadNPagesUp(log, middlepg, NUM_PAGES-1);
-      log->currentpg = middlepg;
-      return;
-    }
-  
-  if (middlepg->isfirstpage)
-    {
-      middlepg = log->firstpg;
-      fseek(fp, mark->offset, SEEK_SET);
-      ReadPageDown(log, middlepg, FALSE /* exec_actions */);
-      ReadNPagesDown(log, middlepg, NUM_PAGES-1);
-      log->currentpg = middlepg;
-      return;
-    }
-  
-  pagesread = ReadNPagesDown (log, middlepg, NUM_PAGES-1);
-  ReadNPagesUp (log, middlepg, MAX (pagesdown, (NUM_PAGES-1-pagesread)));
-
-  log->currentpg = middlepg;
-   
-}
-#endif
-
-
-
-#ifdef FIXME
-/* ----------------------------------------------------------------------
-   NAME:	UpdateLastPage
-   DESCRIPTION:	Re-read the last log page.
-   ---------------------------------------------------------------------- */
-
-void
-UpdateLastPage (Log *log)
-{
-
-  /* Check that the last page is in the list. */
-  if (!log->lastpg->islastpage)
-    return;
-
-
-}
-#endif
-
 /* ----------------------------------------------------------------------
    NAME:          isSameDay
    DESCRIPTION:   Determine if the given times are the same.
    ---------------------------------------------------------------------- */
 
-int
+static int
 isSameDay (time_t day1, time_t day2)
 {
    struct tm d1, d2, *foo;
@@ -1087,10 +780,10 @@ CloseLog (Log * log)
 
    g_return_if_fail (log);
 
-   /* Close file */
-   if (log->fp != NULL) {
-       fclose (log->fp);
-       log->fp = NULL;
+   /* Close file - this should not be needed */
+   if (log->mon_file_handle != NULL) {
+	   gnome_vfs_close (log->mon_file_handle);
+	   log->mon_file_handle = NULL;
    }
 
    /* Free all used memory */
@@ -1117,37 +810,15 @@ CloseLog (Log * log)
 int
 WasModified (Log *log)
 {
-  struct stat filestatus;
-
-  stat (log->name, &filestatus);
-  if (filestatus.st_mtime != log->lstats.mtime) {
-      log->lstats.mtime = filestatus.st_mtime;
-      return TRUE;
-  } else
-      return FALSE;
+	GnomeVFSResult result;
+	GnomeVFSFileInfo info;
 
-}
-
-/* ----------------------------------------------------------------------
-   NAME:        reverse
-   DESCRIPTION: Reverse the string.
-   ---------------------------------------------------------------------- */
-
-void
-reverse (char *line)
-{
-   int i, j, len;
-   char ch;
-
-   len = strlen (line);
-   j = len - 1;
-   for (i = 0; i < (len >> 1); i++)
-   {
-      ch = line[i];
-      line[i] = line[j];
-      line[j] = ch;
-      j--;
-   }
-
-   return;
+	result = gnome_vfs_get_file_info (log->name, 
+					  &(info),
+					  GNOME_VFS_FILE_INFO_DEFAULT);
+	if (info.mtime != log->lstats.mtime) {
+		log->lstats.mtime = info.mtime;
+		return TRUE;
+	} else
+		return FALSE;
 }
